@@ -55,7 +55,7 @@ urlpatterns = patterns('openslides.assignment.views',
         name='assignment_delrun',
     ),
 
-    url(r'^(?P<assignment_id>\d+)/delother/(?P<profile_id>\d+)/$',
+    url(r'^(?P<assignment_id>\d+)/delother/(?P<user_id>[^/]+)/$',
         'delother',
         name='assignment_delother',
     ),
@@ -105,13 +105,13 @@ urlpatterns = patterns('openslides.assignment.views',
         name='assignment_poll_publish_status',
     ),
 
-    url(r'^(?P<assignment_id>\d+)/elected/(?P<profile_id>\d+)/$',
+    url(r'^(?P<assignment_id>\d+)/elected/(?P<user_id>[^/]+)/$',
         'set_elected',
         {'elected': True},
         name='assignment_user_elected',
     ),
 
-    url(r'^(?P<assignment_id>\d+)/notelected/(?P<profile_id>\d+)/$',
+    url(r'^(?P<assignment_id>\d+)/notelected/(?P<user_id>[^/]+)/$',
         'set_elected',
         {'elected': False},
         name='assignment_user_not_elected',
